package org.glassfish.osgi.web.dummy;

import java.io.BufferedReader;
import java.io.File;
import java.io.IOException;
import java.io.InputStreamReader;
import java.net.URL;
import org.glassfish.embeddable.CommandRunner;
import org.glassfish.embeddable.Deployer;
import org.glassfish.embeddable.GlassFish;
import org.glassfish.embeddable.GlassFishException;
import org.glassfish.embeddable.GlassFishProperties;
import org.glassfish.embeddable.GlassFishRuntime;
import org.glassfish.internal.embedded.LifecycleException;
import org.testng.Assert;
import org.testng.annotations.AfterClass;
import org.testng.annotations.BeforeClass;
import org.testng.annotations.Test;

/**
 *
 * @author chaoslayer
 */
public class DummyServletTest
{

    private static final int PORT = 10080;

    private GlassFish glassfish = null;
    private Deployer deployer = null;

    private String currentApp = null;

    static {
        System.setProperty("glassfish.embedded.tmpdir", "target/glassfish");
    }

    @BeforeClass
    public void glassfishStart() throws GlassFishException
    {
       /** Create and start GlassFish */
        GlassFishProperties gf = new GlassFishProperties();
        gf.setPort("http-listener", PORT);

        glassfish = GlassFishRuntime.bootstrap().newGlassFish(gf);
        glassfish.start();

        /** Deploy a web application simple.war with /hello as context root. */
        deployer = glassfish.getService(Deployer.class);
        currentApp = deployer.deploy(new File("target/exploded/dummy-web.war").toURI(),
                "--contextroot=dummy-web", "--force=true");

        CommandRunner commandRunner = glassfish.getService(CommandRunner.class);
    }

    @AfterClass(alwaysRun = true)
    public void glassfishStop() throws GlassFishException
    {
        /** Undeploy the application */
        deployer.undeploy(currentApp);

        /**Stop GlassFish.*/
        glassfish.stop();

        /** Dispose GlassFish. */
        glassfish.dispose();
    }

    @Test
    public void testServlet() throws IOException, LifecycleException, GlassFishException
    {
        // Read the response from the servlet hosted at "/app"
        URL url = new URL("http://localhost:" + PORT + "/dummy-web/dummy");
        BufferedReader br = new BufferedReader(
                new InputStreamReader(
                url.openConnection().getInputStream()));

        // ... and assert
        Assert.assertEquals("Hello Duke", br.readLine());
    }
}
